==> angelscript_2.27.0.zip: sdk/docs/manual/doc_understanding_as.js <==
var doc_understanding_as =
[
    [ "Topics", "doc_understanding_as.html#doc_understading_as_1", null ],
    [ "Script modules", "doc_module.html", [
      [ "Single module versus multiple modules", "doc_module.html#doc_module_single_vs_multi", null ],
      [ "Exchanging information between modules", "doc_module.html#doc_module_exchange", null ]
    ] ],
    [ "Datatypes in AngelScript and C++", "doc_as_vs_cpp_types.html", [
      [ "Primitives", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_1", null ],
      [ "Strings", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_5", null ],
      [ "Arrays", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_2", null ],
      [ "Object handles", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_3", null ],
      [ "Script classes and interfaces", "doc_as_vs_cpp_types.html#doc_as_vc_cpp_types_5", null ],
      [ "Function pointers", "doc_as_vs_cpp_types.html#doc_as_vc_cpp_types_6", null ],
      [ "Parameter references", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_4", null ]
    ] ],
    [ "The string type", "doc_strings.html", [
      [ "Unicode vs ASCII", "doc_strings.html#doc_strings_1", null ],
      [ "Multiline string literals", "doc_strings.html#doc_string_2", null ],
      [ "Character literals", "doc_strings.html#doc_string_3", null ]
    ] ],
    [ "Arrays", "doc_arrays.html", null ],
    [ "Object handles", "doc_obj_handle.html", [
      [ "Managing the reference counter in functions", "doc_obj_handle.html#doc_obj_handle_3", null ],
      [ "Auto handles can make it easier", "doc_obj_handle.html#doc_obj_handle_4", null ]
    ] ],
    [ "Memory management", "doc_memory.html", [
      [ "Overview of the memory management", "doc_memory.html#doc_memory_1", null ],
      [ "Reference counting algorithm", "doc_memory.html#doc_memory_2", null ],
      [ "Garbage collector algorithm", "doc_memory.html#doc_memory_3", null ],
      [ "Memory heap", "doc_memory.html#doc_memory_4", null ]
    ] ]
];

==> angelscript_2.31.2.zip: sdk/docs/manual/doc_understanding_as.js <==
var doc_understanding_as =
[
    [ "Topics", "doc_understanding_as.html#doc_understading_as_1", null ],
    [ "Script modules", "doc_module.html", [
      [ "Single module versus multiple modules", "doc_module.html#doc_module_single_vs_multi", null ],
      [ "Exchanging information between modules", "doc_module.html#doc_module_exchange", null ]
    ] ],
    [ "Datatypes in AngelScript and C++", "doc_as_vs_cpp_types.html", [
      [ "Primitives", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_1", null ],
      [ "Strings", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_5", null ],
      [ "Arrays", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_2", null ],
      [ "Object handles", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_3", null ],
      [ "Script classes and interfaces", "doc_as_vs_cpp_types.html#doc_as_vc_cpp_types_5", null ],
      [ "Function pointers", "doc_as_vs_cpp_types.html#doc_as_vc_cpp_types_6", null ],
      [ "Parameter references", "doc_as_vs_cpp_types.html#doc_as_vs_cpp_types_4", null ]
    ] ],
    [ "The string type", "doc_strings.html", [
      [ "Unicode vs ASCII", "doc_strings.html#doc_strings_1", null ],
      [ "Multiline string literals", "doc_strings.html#doc_string_2", null ],
      [ "Character literals", "doc_strings.html#doc_string_3", null ]
    ] ],
    [ "Arrays", "doc_arrays.html", null ],
    [ "Object handles to the application", "doc_obj_handle.html", [
      [ "Managing the reference counter in functions", "doc_obj_handle.html#doc_obj_handle_3", null ],
      [ "Auto handles can make it easier", "doc_obj_handle.html#doc_obj_handle_4", null ]
    ] ],
    [ "Memory management", "doc_memory.html", [
      [ "Overview of the memory management", "doc_memory.html#doc_memory_1", null ],
      [ "Reference counting algorithm", "doc_memory.html#doc_memory_2", null ],
      [ "Garbage collector algorithm", "doc_memory.html#doc_memory_3", null ],
      [ "Memory heap", "doc_memory.html#doc_memory_4", null ]
    ] ]
];
